@@ -505,6 +505,10 @@ class Tile(ImageWindow):
         ImageWindow.__init__(self, parent, offset, width, height, polygon_mask=polygon_mask)
         self._identifier = tile_identifier
 
+    @property
+    def id(self):
+        return self.identifier 
+        
     @property
     def identifier(self):
         return self._identifier
