@@ -12,7 +12,7 @@ from .locator import BinaryLocator, SemanticLocator
 from .logging import Loggable, SilentLogger
 from .merger import SemanticMerger
 from .timing import WorkflowTiming
-from .util import batch_split
+from .util import batch_split, shape_array
 
 __author__ = "Romain Mormont <romainmormont@hotmail.com>"
 __version = "0.1"
@@ -157,7 +157,7 @@ def _parallel_segment_locate(pool, segmenter, locator, logger, tile_topology, ti
 
     sub_timings, tiles_polygons = list(zip(*results))
     tiles = np.array([tid for result in tiles_polygons for tid, _ in result])
-    tile_polygons = np.array([polygons for result in tiles_polygons for _, polygons in result], dtype=np.object)
+    tile_polygons = shape_array([polygons for result in tiles_polygons for _, polygons in result])
 
     # merge sub timings
     for sub_timing in sub_timings:
